@@ -10,11 +10,11 @@ describe 'magnum::clients::neutron' do
       end
 
       it { is_expected.to contain_magnum_config('neutron_client/region_name').with_value('RegionOne') }
-      it { is_expected.to contain_magnum_config('neutron_client/endpoint_type').with_value('publicURL') }
+      it { is_expected.to contain_magnum_config('neutron_client/endpoint_type').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_magnum_config('neutron_client/ca_file').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_magnum_config('neutron_client/cert_file').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_magnum_config('neutron_client/key_file').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_magnum_config('neutron_client/insecure').with_value(false) }
+      it { is_expected.to contain_magnum_config('neutron_client/insecure').with_value('<SERVICE DEFAULT>') }
     end
 
     context 'with specific parameters' do
