@@ -8,8 +8,8 @@ describe 'magnum::db::sync' do
 
     it 'runs magnum-db-sync' do
       is_expected.to contain_exec('magnum-db-sync').with(
-        :command     => 'magnum-db-manage --config-file /etc/magnum/magnum.conf upgrade head',
-        :path        => '/usr/bin',
+        :command     => 'magnum-db-manage  upgrade head',
+        :path        => ['/bin', '/usr/bin'],
         :user        => 'magnum',
         :refreshonly => 'true',
         :try_sleep   => 5,
@@ -25,17 +25,17 @@ describe 'magnum::db::sync' do
     end
 
     describe "overriding params" do
-    let :params do
-      {
-        :extra_params    => '--config-file /etc/magnum/magnum.conf',
-        :db_sync_timeout => 750,
-      }
-    end
+      let :params do
+        {
+          :extra_params    => '--config-file /etc/magnum/magnum.conf',
+          :db_sync_timeout => 750,
+        }
+      end
 
-    it {
+      it {
         is_expected.to contain_exec('magnum-db-sync').with(
           :command     => 'magnum-db-manage --config-file /etc/magnum/magnum.conf upgrade head',
-          :path        => '/usr/bin',
+          :path        => ['/bin', '/usr/bin'],
           :user        => 'magnum',
           :refreshonly => 'true',
           :try_sleep   => 5,
@@ -48,33 +48,8 @@ describe 'magnum::db::sync' do
           :notify      => 'Anchor[magnum::dbsync::end]',
           :tag         => 'openstack-db',
         )
-    }
-    end
-
-    describe "overriding exec_path" do
-    let :params do
-      {
-        :exec_path => '/opt/venvs/magnum/bin',
       }
     end
-
-    it {
-        is_expected.to contain_exec('magnum-db-sync').with(
-          :command     => 'magnum-db-manage --config-file /etc/magnum/magnum.conf upgrade head',
-          :path        => '/opt/venvs/magnum/bin',
-          :user        => 'magnum',
-          :refreshonly => 'true',
-          :try_sleep   => 5,
-          :tries       => 10,
-          :logoutput   => 'on_failure',
-          :subscribe   => ['Anchor[magnum::install::end]',
-                           'Anchor[magnum::config::end]',
-                           'Anchor[magnum::dbsync::begin]'],
-          :notify      => 'Anchor[magnum::dbsync::end]',
-        )
-    }
-    end
-
   end
 
   on_supported_os({
