@@ -12,7 +12,7 @@ describe 'magnum::keystone::domain' do
     :domain_admin_domain_id   => '16264508d9b6476da952a3971ca9d4b4',
     :domain_admin_email       => 'magnum_admin@localhost',
     :domain_password          => 'domain_passwd',
-    :roles                    => 'admin,',
+    :roles                    => 'admin',
     :keystone_interface       => 'public',
     :keystone_region_name     => 'RegionOne'
     }
@@ -52,6 +52,16 @@ describe 'magnum::keystone::domain' do
       )
     end
 
+    context 'when an array is used for roles' do
+      before do
+        params.merge!(
+          :roles => ['admin', 'manager'],
+        )
+      end
+
+      it { is_expected.to contain_magnum_config('trust/roles').with_value('admin,manager') }
+    end
+
     context 'when not managing the domain creation' do
       before do
         params.merge!(
